@@ -1,9 +1,9 @@
 package RDF::LinkedData;
 
+# Next line is a workaround to problem documented in Error.pm#COMPATIBILITY
+BEGIN { require Moose; Moose->import; *with_role = *with; undef *with };
 
-use Moose;
-
-with 'RDF::LinkedData::ProviderRole';
+with_role 'RDF::LinkedData::ProviderRole';
 
 
 =head1 NAME
@@ -12,11 +12,11 @@ RDF::LinkedData - Linked Data implementation default class
 
 =head1 VERSION
 
-Version 0.09_1
+Version 0.15_1
 
 =cut
 
-our $VERSION = '0.09_1';
+our $VERSION = '0.15_1';
 
 
 =head1 SYNOPSIS
@@ -27,14 +27,15 @@ A simple L<Plack> server illustrates the usage nicely:
   use Plack::Request;
   use RDF::Trine;
 
+  my $parser = RDF::Trine::Parser->new( 'turtle' );
+  my $model = RDF::Trine::Model->temporary_model;
+  my $base_uri = 'http://localhost:5000';
+  $parser->parse_file_into_model( $base_uri, 't/data/basic.ttl', $model );
+  my $ld = RDF::LinkedData->new(model => $model, base=>$base_uri);
+
   $linked_data = sub {
     my $env = shift;
     my $req = Plack::Request->new($env);
-    my $parser = RDF::Trine::Parser->new( 'turtle' );
-    my $model = RDF::Trine::Model->temporary_model;
-    my $base_uri = 'http://localhost:5000';
-    $parser->parse_file_into_model( $base_uri, 't/data/basic.ttl', $model );
-    my $ld = RDF::LinkedData->new(model => $model, base=>$base_uri);
     my $uri = $req->path_info;
     if ($req->path_info =~ m!^(.+?)/?(page|data)$!) {
         $uri = $1;
@@ -49,9 +50,19 @@ A simple L<Plack> server illustrates the usage nicely:
 =head1 METHODS
 
 This module simply uses the default implementation in
-L<RDF::LinkedData::ProviderRole>, and does nothing on its own.
+L<RDF::LinkedData::ProviderRole>, and does nothing on its
+own. However, there is a quirk which is only relevant to a developer
+of this package.
 
+=over
 
+=item with_role
+
+I had to redefine L<Moose::Role>'s with due to a conflict with
+L<Error> described in the documentation of the latter. Users will
+never see this.
+
+=back
 
 =head1 AUTHOR
 
