@@ -1,17 +1,18 @@
 package RDF::LinkedData::ProviderRole;
 
-use Moose::Role;
+# Next line is a workaround to problem documented in Error.pm#COMPATIBILITY
+BEGIN { require Moose::Role; Moose::Role->import; *with_role = *with; undef *with };
 
 use namespace::autoclean;
 
 use RDF::Trine;
-use RDF::Trine::Serializer::NTriples;
-use RDF::Trine::Serializer::RDFXML;
+use RDF::Trine::Serializer;
 use Log::Log4perl qw(:easy);
 use Plack::Response;
 use RDF::Helper::Properties;
+use URI;
 
-with 'MooseX::Log::Log4perl::Easy';
+with_role 'MooseX::Log::Log4perl::Easy';
 
 BEGIN {
     Log::Log4perl->easy_init();
@@ -26,11 +27,11 @@ RDF::LinkedData::ProviderRole - Role providing important functionality for Linke
 
 =head1 VERSION
 
-Version 0.09_1
+Version 0.14
 
 =cut
 
-our $VERSION = '0.09_1';
+our $VERSION = '0.14';
 
 
 =head1 SYNOPSIS
@@ -91,7 +92,7 @@ sub BUILD {
             $self->model(RDF::Trine::Model->new( $store ));
 	}
 
-        throw Error -text => "No valid RDF::Trine::Model, need either a store config string or a model." unless ($self->model);
+        throw Error -text => "No valid RDF::Trine::Model, need either a store config hashref or a model." unless ($self->model);
 
 }
 
@@ -140,16 +141,14 @@ has 'type' => (is => 'rw', isa => 'Str', default => '');
 
 =item C<< my_node >>
 
-A node for the requested B<relative> URI. This node is typically used as
-the subject to find which statements to return as data. Note that the
-base URI, set in the constructor or using the C<base> method, is
-prepended to the argument.
+A node for the requested URI. This node is typically used as the
+subject to find which statements to return as data. This expects to
+get a URI object containing the full URI of the node.
 
 =cut
 
 sub my_node {
-    my ($self, $first) = @_;
-    my $iri	= sprintf( '%s%s', $self->base, $first );
+    my ($self, $iri) = @_;
     
     # not happy with this, but it helps for clients that do content sniffing based on filename
     $iri	=~ s/.(nt|rdf|ttl)$//;
@@ -196,7 +195,8 @@ sub content {
     my %output;
     if ($type eq 'data') {
         $self->{_type} = 'data';
-        my ($type, $s) = RDF::Trine::Serializer->negotiate('request_headers' => $self->headers_in, 
+        my ($type, $s) = RDF::Trine::Serializer->negotiate('request_headers' => $self->headers_in,
+                                                           base => $self->base,
                                                            namespaces => $self->namespaces);
         my $iter = $model->bounded_description($node);
         $output{content_type} = $type;
@@ -249,12 +249,13 @@ Returns or sets the base URI for this handler.
 
 =cut
 
-has base => (is => 'rw', isa => 'Str', default => "http://localhost:3000" );
+has base => (is => 'rw', isa => 'Str' );
 
 
 =item C<< response ( $uri ) >>
 
-Will look up what to do with the given URI and populate the response object.
+Will look up what to do with the given URI object and populate the
+response object.
 
 =cut
 
@@ -274,6 +275,7 @@ sub response {
                 # Then, we have a foaf:page set that we should redirect to
                 $response->status(301);
                 $response->headers->header('Location' => $page);
+                $response->headers->header('Access-Control-Allow-Origin' => '*');
                 return $response;
             }
 
@@ -293,12 +295,14 @@ sub response {
             $response->status(303);
             my $ct;
             eval {
-                ($ct) = RDF::Trine::Serializer->negotiate('request_headers' => $self->headers_in);
+                ($ct) = RDF::Trine::Serializer->negotiate('request_headers' => $self->headers_in,
+                                                          base => $self->base,
+                                                          namespaces => $self->namespaces);
             };
             if ($@) {
                 $ct = 'text/html'; # Set it to HTML for now
             }
-            my $newurl = $self->base . $uri . '/data';
+            my $newurl = $uri . '/data';
             unless ($ct =~ /rdf|turtle/) {
                 my $preds = $self->helper_properties;
                 $newurl = $preds->page($node);
@@ -307,6 +311,7 @@ sub response {
             $response->headers->header('Location' => $newurl);
             $response->headers->header('Vary' => join(", ", qw(Accept)));
         }
+	$response->headers->header('Access-Control-Allow-Origin' => '*');
         return $response;
     } else {
         $response->status(404);
